import React, { useEffect, useRef } from 'react'
// 引入 echarts 核心模块，核心模块提供了 echarts 使用必须要的接口。
import * as echarts from 'echarts/core';
// 引入柱状图图表，图表后缀都为 Chart
import { LineChart } from 'echarts/charts';
// 引入提示框，标题，直角坐标系，数据集，内置数据转换器组件，组件后缀都为 Component
import {
  TitleComponent,
  TooltipComponent,
  GridComponent,
  DatasetComponent,
  TransformComponent,
  DataZoomComponent,
  LegendComponent,
} from 'echarts/components';
// 标签自动布局，全局过渡动画等特性
import { LabelLayout, UniversalTransition } from 'echarts/features';
// 引入 Canvas 渲染器，注意引入 CanvasRenderer 或者 SVGRenderer 是必须的一步
import { CanvasRenderer } from 'echarts/renderers';

// 注册必须的组件
echarts.use([
  TitleComponent,
  TooltipComponent,
  LegendComponent,
  GridComponent,
  DatasetComponent,
  DataZoomComponent,
  TransformComponent,
  LineChart,//折线图
  LabelLayout,
  UniversalTransition,
  CanvasRenderer
]);

export default (props) => {
  const { className, style, option } = props

  const chartRef = useRef()
  const domRef = useRef()

  const styleMerged = {
    height: '100%',
    ...style || {}
  }

  useEffect(() => {
    chartRef.current = echarts.init(domRef.current)

    return () => {
      chartRef.current.dispose()
    }
  }, [])

  useEffect(() => {
    if (chartRef.current && option) {
      chartRef.current.setOption(option)
    }
  }, [option])

  return (
    <div className={className} style={styleMerged} ref={domRef} />
  )
}
