import { useRef,useState } from 'react';
import { Button, Modal, message, Image,Form,Input, InputNumber } from 'antd';
import { PlusOutlined } from '@ant-design/icons';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import PageTable from '@/components/PageTable';
import { getCardNoList,addCarNoBatch } from '@/services/card';
import moment from 'moment';

const formatterTime = (val) => {
  return val && val !== '-' ? moment(val).format('YYYY-MM-DD') : '-';
};
const FormItem = Form.Item;
export default (props) => {
  const actionRef = useRef();

  const formItemLayout = { labelCol: { span: 6 }, wrapperCol: { span: 14 } };
  const [form] = Form.useForm();
  const [visible, setVisible] = useState(false);
  const [loading, setLoading] = useState(false);

  const Submit=(val)=>{
    setLoading(true)
    addCarNoBatch(val).then(()=>{
      message.success('制卡成功，制卡时长较长请10分钟后刷新页面查看卡号')
      onCancel()
      setLoading(false)
    }).catch(err=>{
      console.log(err)
      setLoading(false)
    })
  }
  const onCancel=()=>{
    form.resetFields()
    setVisible(false)
  }

  const actions = () => [
    <Button key="add" type="primary" icon={<PlusOutlined />} onClick={() => setVisible(true)}>
      批量制卡
    </Button>,
  ];
  const columns = [
    {
      title: '卡号',
      key: 'cardNo',
      dataIndex: 'cardNo',
    },
    {
      title: '二维码',
      key: 'qrImage',
      dataIndex: 'qrImage',
      render: (t) => <Image width={110} src={t} alt="" />,
      search:false
    },    
    {
      title: '创建时间',
      key: 'createDate',
      dataIndex: 'createDate',
      render: formatterTime,
    },
  ];

  return (
    <PageHeaderWrapper>
      <PageTable
        columns={columns}
        request={getCardNoList}
        rowKey="qrId"
        options={false}
        toolBarRender={actions}
        actionRef={actionRef}
      />
      <Modal
        forceRender
        title='犬证制卡'
        visible={visible}
        onCancel={onCancel}
        keyboard={false}
        maskClosable={false}
        destroyOnClose={true}
        footer={null}
      >
        <Form {...formItemLayout} onFinish={Submit} form={form}>
          <FormItem label="卡号前缀" name="prefix" rules={[{ required: true, message: '请输入卡号前缀' }]}>
            <Input placeholder="请输入卡号前缀" />
          </FormItem>
          <FormItem label="生成数量" name="num" tooltip='生成数建议1~1000' rules={[{ required: true, message: '请输入正整数' }]}>
            <InputNumber style={{width:'100%'}} min={1} max={1000} placeholder="请输入制卡数量1~1000" />
          </FormItem>
          <FormItem label=" " colon={false}>
            <Button type="default" onClick={onCancel}>
              取消
            </Button>
            <Button
              type="primary"
              loading={loading}
              htmlType="Submit"
              style={{ marginLeft: '4em' }}
            >
              确认
            </Button>
          </FormItem>
        </Form>
      </Modal>
    
    </PageHeaderWrapper>
  );
};
