import React, { useRef } from 'react'
import moment from 'moment';
import { history } from 'umi';
import { DatePicker, Button } from 'antd';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import PageTable from '@/components/PageTable'
import { getMakeList } from '@/services/application'

const { RangePicker } = DatePicker;

const formatterTime = (val) => {
  return val ? moment(val).format('YYYY-MM-DD HH:mm') : '';
};

export default (props) => {
  const actionRef = useRef();
  const goDetail = (id) => {
    history.push(`certificateIssuance/issuance.jsx?id=${id}`);
  }
  const columns = [
    {
      title: '证件号',
      dataIndex: 'originCardNo',
      key: 'originCardNo',
      search: true,
    },
    {
      title: '犬主',
      dataIndex: 'personName',
      key: 'personName',
      search: true,
    },
    {
      title: '犬名',
      dataIndex: 'petName',
      key: 'petName',
      search: true,
    },
    {
      title: '申领方式',
      dataIndex: 'applyMethod',
      key: 'applyMethod',
      search: true,
      render: (_, record) => {
        return record.applyMethod === 1
          ? '上门自取'
          : record.applyMethod === 2
            ? '快递到家' : ''
      },
      valueType: 'select',
      valueEnum: {
        1: { text: '上门自取' },
        2: { text: '快递到家' },
      },
    },
    {
      title: '申请时间',
      dataIndex: 'createDate',
      key: 'createDate',
      render: (t) => formatterTime(t),
      renderFormItem: (_, record) => <RangePicker placeholder={['开始日期', '结束日期']} format='YYYY-MM-DD' />
    },
    {
      title: '制证状态',
      dataIndex: 'makeStatus',
      key: 'makeStatus',
      search: true,// 
      render: (_, record) => {
        return record.makeStatus === 0
          ? '待发放'
          : record.makeStatus === 1
            ? '已发放' : ''
      },
      valueType: 'select',
      valueEnum: {
        0: { text: '待发放' },
        1: { text: '已发放' },
      },
    },
    {
      title: '发放人',
      dataIndex: 'makeUserName',
      key: 'makeUserName',
      search: true,
    },
    {
      title: '发放时间',
      dataIndex: 'makeDate',
      key: 'makeDate',
      render: (t) => t != '-' ? formatterTime(t) : '-',
      renderFormItem: (_, record) => <RangePicker placeholder={['开始日期', '结束日期']} format='YYYY-MM-DD' />
    },
    {
      title: '操作',
      valueType: 'option',
      width: 160,
      render: (_, record) => [
        <Button key={1} style={{ padding: 0 }} type="link"
          onClick={() => goDetail(record.applyId)}
        >
          发证
        </Button>
      ],
    },
  ]


  return (
    <PageHeaderWrapper>
      <PageTable
        actionRef={actionRef}
        columns={columns}
        request={getMakeList}
        options={false}
        rowKey="applyId"
      />
    </PageHeaderWrapper>
  )
}
