import React, { useState, useEffect } from 'react';
import { history } from 'umi';
import { Card, Form, Button, message, Input, Image } from 'antd';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { getApplicationDetail, updateMake } from '@/services/application'

const FormItem = Form.Item;
const formItemLayout = { labelCol: { span: 6 }, wrapperCol: { span: 14 } };
const goBack = () => {
  history.goBack();
};
export default (props) => {
  const { location } = props;
  const { id } = location.query;
  const [application, setApplication] = useState({});
  const [loading, setLoading] = useState(false)
  const [form] = Form.useForm();
  //需要改一下
  const handleMake = (value) => {
    if (value.originCardNo) {
      if (
        (application.applyMethod == 2
          && value.trackingType
          && value.trackingNo)
        || application.applyMethod == 1) {
        setLoading(true)
        var data = {
          cardNo: value.originCardNo,
          makeStatus: application.makeStatus,
          trackingType: value.trackingType,
          trackingNo: value.trackingNo
        }
        updateMake(id, data).then(() => {
          message.success('操作成功');
          goBack()
          setLoading(false)
        }).catch(err => {
          console.log(err.message)
          setLoading(false)
        })
      } else {
        message.success('请输入快递信息');
      }
    }
    else {
      message.success('请输入证件号');
    }
  }
  useEffect(() => {
    getApplicationDetail(id).then((res) => {
      form.setFieldsValue(res);
      setApplication(res)
    }).catch((err) => {
      console.log(err.message)
    });
  }, [id])
  return (
    <PageHeaderWrapper    >
      <Card>
        <Form {...formItemLayout} onFinish={handleMake} form={form}>
          <FormItem label="犬主">
            {application?.personName}
          </FormItem>
          <FormItem label="电话">
            {application?.phone}
          </FormItem>
          <FormItem label="犬名">
            {application?.petName}
          </FormItem>
          <FormItem label="性别">
            {
              application?.petSex == 1 ? '雄' :
                application?.petSex == 2 ? '雌' : '未说明性别'
            }
          </FormItem>
          <FormItem label="犬种">
            {application?.petType}
          </FormItem>
          <FormItem label="毛色">
            {application?.petColor}
          </FormItem>
          <FormItem label="照片">
            <Image src={application?.img1} width={100} />
          </FormItem>
          <FormItem label="养狗地址">
            {application?.address}
          </FormItem>
          <FormItem label="免疫证号">
            {application?.immunizationCode}
          </FormItem>
          <FormItem label="免疫证明">
            <Image src={application?.immunizationImg} width={100} />
          </FormItem>
          <FormItem label="最近免疫日期">
            {application?.immunizationDate}
          </FormItem>
          <FormItem label="申请类型">
            {
              application?.applyType == 'first' ? '办证' :
                application?.applyType == 'reissue' ? '补办' :
                  application?.applyType == 'renewal' ? '续期' : ''
            }
          </FormItem>
          {
            application?.applyType !== 'renewal' &&
            <FormItem label="申领方式">
              {
                application?.applyMethod == '1' ? '上门自取' :
                  application?.applyMethod == '2' ? '快递到家' : ''
              }
            </FormItem>
          }
          <FormItem label="付款状态">
            {
              application.payStatus === 0
                ? '待支付'
                : application.payStatus === 1
                  ? '支付中'
                  : application.payStatus === 2
                    ? '已支付' : ''
            }
          </FormItem>
          <FormItem label="证件号" name='originCardNo' rules={[{ required: true, message: '请输入证件号' }]}>
            <Input
              style={{ width: '350px' }}
              readOnly={application?.makeStatus != 0}
              placeholder='请输入证件号（必填）'
            />
          </FormItem>
          {
            application.applyMethod == 2 && <>
              <FormItem label="快递公司" name='trackingType' rules={[{ required: true, message: '请输入快递公司' }]}>
                <Input
                  style={{ width: '350px' }}
                  placeholder='请输入快递公司（必填）'
                  readOnly={application?.makeStatus != 0}
                 />
              </FormItem>
              <FormItem label="快递单号" name='trackingNo' rules={[{ required: true, message: '请输入快递公司' }]}>
                <Input
                  style={{ width: '350px' }}
                  placeholder='请输入快递单号（必填）'
                  readOnly={application?.makeStatus != 0}
                />
              </FormItem>
            </>
          }
          <FormItem label=" " colon={false}>
            {
              application?.makeStatus == 0 &&
              <>
                <Button type="primary" loading={loading}
                htmlType="Submit"
                  style={{ marginRight: '16px' }}>
                  发放
                </Button>
              </>
            }
            <Button type="default" onClick={() => goBack()}>
              返回
            </Button>
          </FormItem>
        </Form>
      </Card>
    </PageHeaderWrapper>
  );
};
