import moment from 'moment'
import { Card, List, Image, Space, Carousel } from 'antd'
import { useEffect, useMemo, useState } from 'react'
import { getApplicationList } from '@/services/application'

const Avatar = (props) => {
  const style = useMemo(() => {
    return {
      width: '48px',
      height: '48px',
    }
  }, [])
  return <div style={style}><Image src={props.item.img1} width='100%' height='100%' /></div>
}


const Content = (props) => {
  const { item } = props;

  return (
    <Space size="large">
      <span>{moment(item.createDate).format('YYYY-MM-DD HH:mm')}</span>
    </Space>
  )
}

const showNum = 8;

export default (props) => {
  const [loading, setLoading] = useState(false)
  const [disabled, setDisabled] = useState(false)
  const [list, setList] = useState([])
  useEffect(() => {
    setDisabled(!list || list.length <= showNum)
  }, [list])
  useEffect(() => {
    setLoading(true)
    getApplicationList({ pageSize: 50 }).then((res) => {
      setList(res.records.map(item => {
        if (item.applyType == 'first') {
          item.applyTypeName = '办证'
        } else if (item.applyType == 'renewal') {
          item.applyTypeName = '续期'
        } else {
          item.applyTypeName = '补办'
        }
        return item
      })
      )
      setLoading(false)
    }).catch(err => {
      console.log(err);
      setLoading(false)
    })
  }, [])

  return (
    <Card title="近期提交记录" loading={loading} bodyStyle={{ height: '616px' }}>
      <List style={{ height: '100%', overflow: 'hidden' }} itemLayout="horizontal">
        <Carousel
          autoplay={!disabled}
          infinite={!disabled}
          rtl
          slidesToShow={showNum}
          slidesToScroll={1}
          dot={false}
          dotPosition="right"
          style={{ height: '100%' }}
        >
          {
            list.map(item => (
              <div key={item.applyId} style={{ display: 'flex' }}>
                <List.Item>
                  <List.Item.Meta
                    avatar={<Avatar item={item} />}
                    title={item.petName}
                    description={'【'+item.applyTypeName + `】  申请人：` + item.personName }
                  />
                  <Content item={item} />
                </List.Item>
              </div>
            ))
          }
        </Carousel>
      </List>
    </Card>
  )
}
