import { useEffect, useState, useRef } from 'react';
import { history } from 'umi';
import { Input, Card, Select, Button, Form, InputNumber, message } from 'antd';
import ProCard from '@ant-design/pro-card';
import { addNotice, updateNotice, getNoticeDetail } from '@/services/notice'
import RichEditor from "@/components/rich-editor";


const { Option } = Select;
const goBack = () => {
  history.goBack();
};
const FormItem = Form.Item;
export default (props) => {
  const { location } = props;
  const { id } = location.query;
  const [form] = Form.useForm();
  const [loading, setLoading] = useState(false);
  const [data, setData] = useState();

  const editorRef = useRef()

  const formItemLayout = {
    //布局
    labelCol: { span: 6 },
    wrapperCol: { span: 14 },
  };

  const Submit = (value) => {
    var myData = { ...data, ...value };
    setLoading(true);
    if (id) {
      updateNotice(id, myData)
        .then(() => {
          setLoading(false);
          message.success('数据更新成功');
          goBack();
        })
        .catch((err) => {
          setLoading(false);
          message.error(err.message || err);
        });
    } else {
      addNotice(myData)
        .then((res) => {
          setLoading(false);
          message.success('数据保存成功');
          history.replace(`./edit.jsx?id=${res.noticeId}`);
        })
        .catch((err) => {
          setLoading(false);
          message.error(err.message || err);
        });
    }
  };
  useEffect(() => {
    if (id && form) {
      getNoticeDetail(id).then((res) => {
        form.setFieldsValue(res);
        setData(res);
        editorRef.current.setContent(res.content);
      }).catch((err) => {
        console.log(err.message)
      });
    }
  }, [id, form]);

  return (
    <Card>
      <ProCard tabs={{ type: 'card' }} style={{ marginTop: '16px' }}>
        <ProCard.TabPane key={1} tab="通知编辑">
          <Form {...formItemLayout} onFinish={Submit} form={form}>
            <FormItem label="标题" name="title" rules={[{ required: true, message: '请输入' }]}>
              <Input placeholder="请输入" style={{ width: '350px' }} />
            </FormItem>
            <FormItem label="正文" name='content' rules={[{ required: true, message: '请输入' }]}>
              <RichEditor ref={editorRef} />
            </FormItem>
            <FormItem label="权重" name="weight" rules={[{ required: true, message: '请输入' }]}>
              <InputNumber min={0} placeholder="请输入权重" style={{ width: '350px' }} />
            </FormItem>
            <FormItem label="状态" name="status" rules={[{ required: true, message: '请选择' }]}>
              <Select placeholder="请选择是否发布" style={{ width: '350px' }}>
                <Option value={1}>发布</Option>
                <Option value={0}>未发布</Option>
              </Select>
            </FormItem>
            <FormItem label=" " colon={false}>
              <Button
                type="default"
                onClick={() => goBack()}
              >
                返回
              </Button>
              <Button
                type="primary"
                loading={loading}
                htmlType="Submit"
                style={{ marginLeft: '4em' }}
              >
                保存
              </Button>
            </FormItem>
          </Form>
        </ProCard.TabPane>
      </ProCard>
    </Card>
  );
};
