import React, { useRef } from 'react'
import moment from 'moment';
import { DatePicker } from 'antd';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import PageTable from '@/components/PageTable'
import { getPersonList } from '@/services/person'

const { RangePicker } = DatePicker;

const formatterTime = (val) => {
  return val ? moment(val).format('YYYY-MM-DD HH:mm') : '';
};

export default (props) => {

  const actionRef = useRef();
  const columns = [
    {
      title: '姓名',
      dataIndex: 'nickName',
      key: 'nickName',
      search: true,
    },
    {
      title: '手机号',
      dataIndex: 'phone',
      key: 'phone',
      search: true,
    },
    {
      title: '注册时间',
      dataIndex: 'createDate',
      key: 'createDate',
      render: (t) => formatterTime(t),
      renderFormItem: (_, record) => <RangePicker placeholder={['开始日期', '结束日期']} format='YYYY-MM-DD' />
    },
  ]

  return (
    <PageHeaderWrapper>
      <PageTable
        actionRef={actionRef}
        columns={columns}
        request={getPersonList}
        options={false}
        rowKey="personId"
      />
    </PageHeaderWrapper>
  )
}
